@@ -9,7 +9,7 @@
 import ast
 import subprocess
 
-from scriptengine.tasks import Task
+from scriptengine.tasks.base import Task
 from scriptengine.jinja import render as j2render
 from scriptengine.exceptions import ScriptEngineStopException
 
