@@ -3,7 +3,7 @@
 import os
 import fnmatch
 
-from scriptengine.tasks import Task
+from scriptengine.tasks.base import Task
 from scriptengine.jinja import render as j2render
 from scriptengine.exceptions import ScriptEngineStopException
 
