@@ -2,7 +2,7 @@
 
 import os
 
-from scriptengine.tasks import Task
+from scriptengine.tasks.base import Task
 from scriptengine.jinja import render as j2render
 
 
